rmtoo

# project

This is placeholder for some introductional text.

## project

Description
  project must exists.
Rationale

  The world needs a good, usable and free project.

Dependent
  req1
Id
  project
Priority
  10.00
Owner
  development
Invented on
  2010-10-09
Invented by
  flonatel
Status
  not done
Class
  detailable

- What's all about

This document is part of the rmtoo requirements documentation and was generated by rmtoo itself.

rmtoo is copyright 2010 by flonatel. rmtoo is distributed under GPL V3.